@@ -8,8 +8,6 @@ from reliably_cli.config import get_settings
 from reliably_cli.log import logger
 from reliably_cli.oltp import oltp_span
 
-from . import fetch_deployment
-
 __all__ = ["schedule_plan"]
 
 
@@ -24,16 +22,12 @@ async def schedule_plan(plan: Plan) -> None:
             ):
                 logger.info(f"Schedule plan {plan.id} on GitHub")
 
-                deployment = await fetch_deployment(plan, settings)
-                gh_token = deployment["definition"]["token"]
-                if gh_token is None:
-                    logger.debug("Using the environment GITHUB_TOKEN")
-                    gh_token = os.getenv("GITHUB_TOKEN")
+                gh_token = os.getenv("GITHUB_TOKEN")
 
                 if not gh_token:
                     raise RuntimeError(
                         "you must specify a suitable GitHub token, either in "
-                        "the Reliably configuration file or via the"
+                        "the Reliably configuration file or via the "
                         "GITHUB_TOKEN environment variable"
                     )
 
@@ -56,8 +50,6 @@ async def schedule_plan(plan: Plan) -> None:
                     "GITHUB_REF_NAME", settings.plan.providers.github.ref
                 )
 
-                reliably_token = settings.agent.token.get_secret_value()
-
                 url = (
                     f"{gh_api_url}/repos/{gh_repo}/actions"
                     f"/workflows/{gh_workflow_id}/dispatches"
@@ -75,7 +67,6 @@ async def schedule_plan(plan: Plan) -> None:
                             "ref": gh_ref,
                             "inputs": {
                                 "experiment-url": experiment_url,
-                                "reliably-agent-token": reliably_token,
                                 "environment-name": "myenv",
                             },
                         },
